@@ -1,20 +1,8 @@
 /*
 
-  Copyright (c) 2011-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2011-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "filteractionmissingfolderdialog.h"
@@ -40,11 +28,10 @@
 FilterActionMissingFolderDialog::FilterActionMissingFolderDialog(
     const Akonadi::Collection::List &list, const QString &filtername, const QString &argStr, QWidget *parent)
     : QDialog(parent)
-    , mListwidget(nullptr)
 {
     setModal(true);
-    setWindowTitle(i18n("Select Folder"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    setWindowTitle(i18nc("@title:window", "Select Folder"));
+    auto *mainLayout = new QVBoxLayout(this);
 
     QLabel *lab = new QLabel(i18n("Folder path was \"%1\".", argStr));
     lab->setObjectName(QStringLiteral("argumentlabel"));
@@ -59,7 +46,7 @@ FilterActionMissingFolderDialog::FilterActionMissingFolderDialog(
         mainLayout->addWidget(mListwidget);
         const int numberOfItems(list.count());
         for (int i = 0; i < numberOfItems; ++i) {
-            Akonadi::Collection col = list.at(i);
+            const Akonadi::Collection col = list.at(i);
             QListWidgetItem *item = new QListWidgetItem(MailCommon::Util::fullCollectionPath(col));
             item->setData(FilterActionMissingFolderDialog::IdentifyCollection, col.id());
             mListwidget->addItem(item);
